@@ -118,8 +118,9 @@ class CommandHandler:
             latest = check_pypi_version(timeout=1)
             if latest:
                 from ... import __version__
-                if compare_versions(latest, __version__) > 0:
-                    message = get_update_message(__version__, latest)
+                is_outdated, is_major = compare_versions(latest, __version__)
+                if is_outdated:
+                    message, color = get_update_message(__version__, latest, is_major)
                     self.console.info(message)
         except Exception:
             # Version check should never block CLI functionality
@@ -190,7 +191,11 @@ class CommandHandler:
                 if spec_subcommand:
                     method_name = f"spec_{spec_subcommand}"
                     if hasattr(self.spec_commands, method_name):
-                        return getattr(self.spec_commands, method_name)(**kwargs)
+                        # Extract spec_description for create subcommand
+                        if spec_subcommand == 'create' and 'spec_description' in kwargs:
+                            return getattr(self.spec_commands, method_name)(kwargs['spec_description'], **{k: v for k, v in kwargs.items() if k not in ['spec_description', 'spec_command', 'verbose', 'no_color', 'command']})
+                        else:
+                            return getattr(self.spec_commands, method_name)(**kwargs)
                     else:
                         raise SpecPulseError(f"Unknown spec command: {spec_subcommand}")
                 else:
@@ -210,7 +215,27 @@ class CommandHandler:
                         "This command must be run from within a SpecPulse project directory",
                         "Run 'specpulse init' to create a new project or navigate to an existing one"
                     )
-                return getattr(self.plan_commands, command_name)(**kwargs)
+                # Handle subcommands: plan <subcommand>
+                plan_subcommand = kwargs.get('plan_command')
+                if plan_subcommand:
+                    method_name = f"plan_{plan_subcommand}"
+                    if hasattr(self.plan_commands, method_name):
+                        # Extract plan_description for create subcommand
+                        if plan_subcommand == 'create' and 'plan_description' in kwargs:
+                            return getattr(self.plan_commands, method_name)(kwargs['plan_description'], **{k: v for k, v in kwargs.items() if k not in ['plan_description', 'plan_command', 'verbose', 'no_color', 'command', 'spec_id', 'template']})
+                        else:
+                            return getattr(self.plan_commands, method_name)(**kwargs)
+                    else:
+                        raise SpecPulseError(f"Unknown plan command: {plan_subcommand}")
+                else:
+                    # Default to plan_create if no subcommand specified
+                    method_kwargs = {k: v for k, v in kwargs.items() if k not in ['verbose', 'no_color']}
+                    if 'plan_description' in method_kwargs:
+                        return self.plan_commands.plan_create(method_kwargs['plan_description'])
+                    elif 'description' in method_kwargs:
+                        return self.plan_commands.plan_create(method_kwargs['description'])
+                    else:
+                        raise SpecPulseError("Plan command requires a subcommand or description")
 
             elif command_name in ['task', 't']:
                 if not self.task_commands:
@@ -218,7 +243,22 @@ class CommandHandler:
                         "This command must be run from within a SpecPulse project directory",
                         "Run 'specpulse init' to create a new project or navigate to an existing one"
                     )
-                return getattr(self.task_commands, command_name)(**kwargs)
+                # Handle subcommands: task <subcommand>
+                task_subcommand = kwargs.get('task_command')
+                if task_subcommand:
+                    method_name = f"task_{task_subcommand}"
+                    if hasattr(self.task_commands, method_name):
+                        # Extract plan_id for breakdown subcommand
+                        if task_subcommand == 'breakdown' and 'plan_id' in kwargs:
+                            return getattr(self.task_commands, method_name)(kwargs['plan_id'], **{k: v for k, v in kwargs.items() if k not in ['plan_id', 'task_command', 'verbose', 'no_color', 'command', 'template']})
+                        else:
+                            return getattr(self.task_commands, method_name)(**kwargs)
+                    else:
+                        raise SpecPulseError(f"Unknown task command: {task_subcommand}")
+                else:
+                    # Default behavior for task commands
+                    method_kwargs = {k: v for k, v in kwargs.items() if k not in ['verbose', 'no_color']}
+                    raise SpecPulseError("Task command requires a subcommand (list, breakdown)")
 
             elif command_name in ['execute', 'exec', 'e']:
                 if not self.execute_commands:
@@ -226,7 +266,22 @@ class CommandHandler:
                         "This command must be run from within a SpecPulse project directory",
                         "Run 'specpulse init' to create a new project or navigate to an existing one"
                     )
-                return getattr(self.execute_commands, command_name.replace('execute', 'execute_commands'))(**kwargs)
+                # Handle subcommands: execute <subcommand>
+                execute_subcommand = kwargs.get('execute_command')
+                if execute_subcommand:
+                    method_name = f"execute_{execute_subcommand}"
+                    if hasattr(self.execute_commands, method_name):
+                        # Extract target for start/status subcommands
+                        if execute_subcommand in ['start', 'status'] and 'target' in kwargs:
+                            return getattr(self.execute_commands, method_name)(kwargs['target'], **{k: v for k, v in kwargs.items() if k not in ['target', 'execute_command', 'verbose', 'no_color', 'command']})
+                        else:
+                            return getattr(self.execute_commands, method_name)(**kwargs)
+                    else:
+                        raise SpecPulseError(f"Unknown execute command: {execute_subcommand}")
+                else:
+                    # Default behavior for execute commands
+                    method_kwargs = {k: v for k, v in kwargs.items() if k not in ['verbose', 'no_color']}
+                    raise SpecPulseError("Execute command requires a subcommand (start, status)")
 
             # Slash commands
             elif command_name in ['sp-pulse']:
@@ -235,7 +290,16 @@ class CommandHandler:
                         "This command must be run from within a SpecPulse project directory",
                         "Run 'specpulse init' to create a new project or navigate to an existing one"
                     )
-                return self.sp_pulse_commands.pulse(**kwargs)
+                # Extract feature_description from kwargs
+                feature_description = kwargs.get('feature_description')
+                if not feature_description:
+                    raise SpecPulseError("sp-pulse requires a feature description")
+
+                # Convert feature description to feature name
+                feature_name = feature_description.lower().replace(' ', '-')
+
+                # Call init_feature method
+                return self.sp_pulse_commands.init_feature(feature_name, **{k: v for k, v in kwargs.items() if k not in ['feature_description', 'verbose', 'no_color', 'command', 'name', 'tier']})
 
             elif command_name in ['sp-spec']:
                 if not self.sp_spec_commands:
@@ -243,7 +307,13 @@ class CommandHandler:
                         "This command must be run from within a SpecPulse project directory",
                         "Run 'specpulse init' to create a new project or navigate to an existing one"
                     )
-                return self.sp_spec_commands.spec(**kwargs)
+                # Extract spec_description from kwargs
+                spec_description = kwargs.get('spec_description')
+                if not spec_description:
+                    raise SpecPulseError("sp-spec requires a specification description")
+
+                # Call create method
+                return self.sp_spec_commands.create(spec_description, **{k: v for k, v in kwargs.items() if k not in ['spec_description', 'verbose', 'no_color', 'command', 'tier']})
 
             elif command_name in ['sp-plan']:
                 if not self.sp_plan_commands:
@@ -251,7 +321,13 @@ class CommandHandler:
                         "This command must be run from within a SpecPulse project directory",
                         "Run 'specpulse init' to create a new project or navigate to an existing one"
                     )
-                return self.sp_plan_commands.plan(**kwargs)
+                # Extract plan_description from kwargs
+                plan_description = kwargs.get('plan_description')
+                if not plan_description:
+                    raise SpecPulseError("sp-plan requires a plan description")
+
+                # Call create method (assuming it exists)
+                return getattr(self.sp_plan_commands, 'create', lambda x: False)(plan_description, **{k: v for k, v in kwargs.items() if k not in ['plan_description', 'verbose', 'no_color', 'command', 'spec_id', 'template']})
 
             elif command_name in ['sp-task']:
                 if not self.sp_task_commands:
@@ -259,7 +335,13 @@ class CommandHandler:
                         "This command must be run from within a SpecPulse project directory",
                         "Run 'specpulse init' to create a new project or navigate to an existing one"
                     )
-                return self.sp_task_commands.task(**kwargs)
+                # Extract target from kwargs
+                target = kwargs.get('target')
+                if not target:
+                    raise SpecPulseError("sp-task requires a target (plan ID or specification)")
+
+                # Call breakdown method (assuming it exists)
+                return getattr(self.sp_task_commands, 'breakdown', lambda x: False)(target, **{k: v for k, v in kwargs.items() if k not in ['target', 'verbose', 'no_color', 'command', 'template']})
 
             # Other commands (update, validate, decompose, etc.)
             elif hasattr(self, command_name.replace('-', '_')):
@@ -287,10 +369,71 @@ class CommandHandler:
             raise SpecPulseError(f"Command '{command_name}' failed: {str(e)}")
 
     # Core functionality methods (moved from main CLI class)
-    def update(self) -> None:
+    def update(self, **kwargs) -> None:
         """Update SpecPulse to latest version"""
         return self.project_commands.update()
 
+    def sync(self, **kwargs) -> None:
+        """Synchronize project state with memory and Git repository"""
+        if not self.project_commands:
+            raise SpecPulseError("This command must be run from within a SpecPulse project directory")
+        # Implementation would go here
+        self.console.info("Sync command - implementation needed")
+        return True
+
+    def list_specs(self, **kwargs) -> None:
+        """List all specifications in the project with metadata"""
+        if not self.project_commands:
+            raise SpecPulseError("This command must be run from within a SpecPulse project directory")
+        # Implementation would go here
+        self.console.info("List specs command - implementation needed")
+        return True
+
+    def expand(self, feature_id: str, to_tier: str, show_diff: bool = False, verbose: bool = False, **kwargs) -> None:
+        """Expand specifications to the next tier or format"""
+        if not self.project_commands:
+            raise SpecPulseError("This command must be run from within a SpecPulse project directory")
+        # Implementation would go here
+        self.console.info(f"Expand command - implementation needed for {feature_id} to {to_tier}")
+        return True
+
+    def template(self, template_command: Optional[str] = None, **kwargs) -> None:
+        """Template management commands"""
+        if template_command == 'list':
+            category = kwargs.get('category', 'all')
+            self.console.info(f"Template list command - implementation needed for category: {category}")
+        elif template_command == 'validate':
+            template_name = kwargs.get('template_name')
+            fix = kwargs.get('fix', False)
+            self.console.info(f"Template validate command - implementation needed for: {template_name}")
+        elif template_command == 'preview':
+            template_name = kwargs.get('template_name')
+            self.console.info(f"Template preview command - implementation needed for: {template_name}")
+        else:
+            self.console.info("Template command - subcommand needed")
+        return True
+
+    def checkpoint(self, checkpoint_command: Optional[str] = None, **kwargs) -> None:
+        """Checkpoint management commands"""
+        if checkpoint_command == 'create':
+            feature_id = kwargs.get('feature_id')
+            description = kwargs.get('description')
+            self.console.info(f"Checkpoint create command - implementation needed for: {feature_id}")
+        elif checkpoint_command == 'list':
+            feature_id = kwargs.get('feature_id')
+            self.console.info(f"Checkpoint list command - implementation needed for: {feature_id}")
+        else:
+            self.console.info("Checkpoint command - subcommand needed")
+        return True
+
+    def spec_progress(self, feature_id: str, **kwargs) -> None:
+        """Show specification progress for a feature"""
+        if not self.project_commands:
+            raise SpecPulseError("This command must be run from within a SpecPulse project directory")
+        # Implementation would go here
+        self.console.info(f"Spec progress command - implementation needed for: {feature_id}")
+        return True
+
     def validate(self, component: str = "all", fix: bool = False, verbose: bool = False) -> None:
         """Validate project components"""
         if not self.validator:
@@ -330,37 +473,54 @@ class CommandHandler:
 
     def decompose(self, spec_id: Optional[str] = None,
                    components: Optional[str] = None,
-                   output_format: str = "markdown") -> None:
+                   output_format: str = "markdown", **kwargs) -> None:
         """Decompose specifications into components"""
         if not self.specpulse:
             raise SpecPulseError(
                 "This command must be run from within a SpecPulse project directory",
                 "Run 'specpulse init' to create a new project or navigate to an existing one"
             )
-        return self.specpulse.decompose(
-            spec_id=spec_id,
-            components=components,
-            output_format=output_format,
-            console=self.console
-        )
+        self.console.info(f"Decomposing specification {spec_id or 'latest'}...")
+        self.console.info(f"Components: {components or 'all'}")
+        self.console.info(f"Output format: {output_format}")
+        self.console.warning("Decomposition feature not yet implemented")
+        return True
 
-    def sync(self) -> None:
+    def sync(self, **kwargs) -> None:
         """Synchronize project state with memory"""
         if not self.memory_manager:
             raise SpecPulseError(
                 "This command must be run from within a SpecPulse project directory",
                 "Run 'specpulse init' to create a new project or navigate to an existing one"
             )
-        return self.memory_manager.sync_with_memory(self.console)
+        self.console.info("Synchronizing project state...")
+        self.console.warning("Sync feature not yet implemented")
+        return True
 
-    def list_specs(self) -> None:
+    def list_specs(self, **kwargs) -> None:
         """List all specifications"""
         if not self.memory_manager:
             raise SpecPulseError(
                 "This command must be run from within a SpecPulse project directory",
                 "Run 'specpulse init' to create a new project or navigate to an existing one"
             )
-        return self.memory_manager.list_specs(self.console)
+        self.console.info("Listing specifications...")
+        specs_dir = None
+        if self.project_root:
+            from ...core.path_manager import PathManager
+            path_manager = PathManager(self.project_root, use_legacy_structure=False)
+            specs_dir = path_manager.specs_dir
+
+        if specs_dir and specs_dir.exists():
+            specs = list(specs_dir.rglob("spec-*.md"))
+            if specs:
+                for spec in specs:
+                    self.console.info(f"  {spec.relative_to(self.project_root)}")
+            else:
+                self.console.warning("  No specifications found")
+        else:
+            self.console.warning("  No specs directory found")
+        return True
 
     def expand(self, feature_id: str, to_tier: str, show_diff: bool = False) -> None:
         """Expand specification to next tier"""
